module.exports = defineTest({
	description: 'handles slashes in function parameters and correctly inserts missing ids'
});
